@@ -143,7 +143,7 @@ std::ostream& operator<<(std::ostream &out, QNetworkReply::NetworkError err) {
 
 namespace {
     const QString PROPERTIES_INTERFACE = "org.freedesktop.DBus.Properties";
-    const QString DOWNLOAD_INTERFACE = "com.canonical.applications.Download";
+    const QString DOWNLOAD_INTERFACE = "com.lomiri.applications.Download";
     const QString PROPERTIES_CHANGED = "PropertiesChanged";
     const QString CLICK_PACKAGE_PROPERTY = "ClickPackage";
     const QString SHOW_INDICATOR_PROPERTY = "ShowInIndicator";
